
# Resources

## Other python packages

### Data generation

**Faker**: a Python package that generates fake data for you.
https://faker.readthedocs.io 

#### Fake tabular data generation
- https://gitlab.com/healthdatahub/tsfaker
- https://github.com/tirthajyoti/pydbgen
- https://github.com/plaitpy/plaitpy
- https://github.com/EDS-APHP-legacy/pySyntheticDatasetGenerator

#### Fake time series generation
- https://github.com/aphp/dsfaker

### Data Augmentation

#### Natural Language Processing
**NLPaug**: Data augmentation for NLP
https://makcedward.github.io/ 


#### Computer vision

**Augmentor**: a Python package designed to aid the augmentation and artificial generation of image data for machine learning tasks.
https://augmentor.readthedocs.io/en/stable/

**Albumentations**: Fast image augmentation library and an easy-to-use wrapper around other libraries.
https://github.com/albumentations-team/albumentations

**Imgaug**: a library for image augmentation in machine learning experiments. 
https://imgaug.readthedocs.io/en/latest/

### Data quality issues detection

**Pyod**:  A Comprehensive and Scalable Python Library for Outlier Detection (Anomaly Detection)
https://pyod.readthedocs.io 

**Autoimpute**: a Python package for analysis and implementation of Imputation Methods.
https://autoimpute.readthedocs.io/en/latest/

**Imbalanced-learn**: a Python Package to Tackle the Curse of Imbalanced Datasets in Machine Learning
https://imbalanced-learn.org/stable/

## Blog posts

https://neptune.ai/blog/data-augmentation-nlp

https://neptune.ai/blog/data-augmentation-in-python

## Scientific literature

### Outliers generation 

Georg Steinbuss and Klemens Böhm. 2021. Generating Artificial Outliers in the Absence of Genuine Ones — A Survey. ACM Trans. Knowl. Discov. Data 15, 2, Article 30 (April 2021), 37 pages. https://doi.org/10.1145/3447822

Marian Turowski, Moritz Weber, Oliver Neumann, Benedikt Heidrich, Kaleb Phipps, Hüseyin K. Çakmak, Ralf Mikut, and Veit Hagenmeyer. 2022. Modeling and generating synthetic anomalies for energy and power time series. In Proceedings of the Thirteenth ACM International Conference on Future Energy Systems (e-Energy '22). Association for Computing Machinery, New York, NY, USA, 471–484. https://doi.org/10.1145/3538637.3539760

### Missing Values

Santos, M.S., Pereira, R.C., Costa, A.F., Soares, J.P., Santos, J., & Abreu, P.H. (2019). Generating Synthetic Missing Data: A Review by Missing Mechanism. IEEE Access, 7, 11651-11667. https://ieeexplore.ieee.org/document/8605316